"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Element = __importStar(require("../element"));
const Api_1 = require("../Api");
const logger_1 = __importDefault(require("../logger"));
const sessionInfo_1 = __importDefault(require("../sessionInfo"));
function DragAndDropBuilder(body, driver) {
    const driverInfo = (0, sessionInfo_1.default)(driver);
    return {
        dragAndDrop: dragAndDrop(body, driverInfo),
    };
}
exports.default = DragAndDropBuilder;
function dragAndDrop(body, driverInfo) {
    return __awaiter(this, void 0, void 0, function* () {
        const sourceElementUrl = `${driverInfo.driverUrl}/element/${body.sourceId}`;
        const destinationElementUrl = `${driverInfo.driverUrl}/element/${body.destinationId}`;
        const [source, destination] = yield Promise.all([
            Element.getElementRect(sourceElementUrl),
            Element.getElementRect(destinationElementUrl),
        ]);
        console.log('Source', source, 'Destination', destination);
        const [{ x: sourceX, y: sourceY }, { x: destinationX, y: destinationY }] = yield Promise.all([
            Element.getCenter(source),
            Element.getCenter(destination),
        ]);
        const androidPauseAction = {
            duration: 0,
            type: 'pause',
        };
        const actionsData = {
            actions: [
                {
                    id: 'finger',
                    type: 'pointer',
                    parameters: {
                        pointerType: 'touch',
                    },
                    actions: [
                        {
                            duration: 0,
                            x: sourceX,
                            y: sourceY,
                            type: 'pointerMove',
                            origin: 'viewport',
                        },
                        {
                            button: 1,
                            type: 'pointerDown',
                        },
                        {
                            duration: 600,
                            type: 'pause',
                        },
                        {
                            duration: 600,
                            x: destinationX,
                            y: destinationY,
                            type: 'pointerMove',
                            origin: 'viewport',
                        },
                        {
                            button: 1,
                            type: 'pointerUp',
                        },
                    ],
                },
            ],
        };
        let actionsUrl = `${driverInfo.driverUrl}/actions`;
        logger_1.default.info(`Performing Drag and Drop ${actionsUrl} with ${JSON.stringify(actionsData)}`);
        if (driverInfo.automationName === 'XCuiTest') {
            yield (0, Api_1.post)({
                url: actionsUrl,
                data: actionsData,
            });
        }
        else {
            logger_1.default.info('Drag and Drop for android');
            const androidActions = actionsData;
            androidActions.actions[0].actions.unshift(androidPauseAction);
            yield (0, Api_1.post)({
                url: actionsUrl,
                data: androidActions,
            });
        }
    });
}
